# Created byMartin.cz
# Copyright (c) Martin Strohalm. All rights reserved.

# define tokens
API_KEY = None
USER_TOKEN = None

# define API urls
API_LEGO_URL = "https://rebrickable.com/api/v3/lego/"
API_USERS_URL = "https://rebrickable.com/api/v3/users/"

# define image urls
LEGO_ELEMENT_IMG_URL = "https://www.lego.com/cdn/product-assets/element.img.lod5photo.192x192/{0}.jpg"
RB_ELEMENT_IMG_URL = "https://cdn.rebrickable.com/media/parts/elements/{0}.jpg/192x192xp.jpg"
RB_SET_IMG_URL = "https://m.rebrickable.com/media/sets/{0}.jpg"

# define minimum delay between requests in seconds
REQUEST_DELAY = 1.1
